@@ -4,11 +4,12 @@ use strict;
 use warnings;
 
 use base qw/DBIx::Class/;
-use Digest;
+use Sub::Name;
 
-__PACKAGE__->mk_classdata( _column_encoders => {} );
+__PACKAGE__->mk_classdata( '_column_encoders' );
 
-our $VERSION = '0.00001_03';
+our $VERSION = '0.00009_1';
+$VERSION = eval $VERSION;
 
 sub register_column {
   my $self = shift;
@@ -30,18 +31,20 @@ sub register_column {
 
   defined( my $encode_sub = eval{ $class->make_encode_sub($column, $args) }) ||
     $self->throw_exception("Failed to create encoder with class '$class': $@");
-  $self->_column_encoders->{$column} = $encode_sub;
+  $self->_column_encoders({$column => $encode_sub, %{$self->_column_encoders || {}}});
 
   if ( exists $info->{encode_check_method} && $info->{encode_check_method} ){
     no strict 'refs';
     defined( my $check_sub = eval{ $class->make_check_sub($column, $args) }) ||
       $self->throw_exception("Failed to create checker with class '$class': $@");
-    *{$self->result_class.'::'.$info->{encode_check_method}} = $check_sub;
+    my $name = join '::', $self->result_class, $info->{encode_check_method};
+    *$name = subname $name, $check_sub;
   }
 }
 
 sub set_column {
   my $self = shift;
+  return $self->next::method(@_) unless defined $_[1];
   my $encs = $self->_column_encoders;
   if(exists $encs->{$_[0]} && defined(my $encoder = $encs->{$_[0]})){
     return $self->next::method($_[0], $encoder->($_[1]));
@@ -103,7 +106,7 @@ In your L<DBIx::Class> Result class
       encode_column => 1,
       encode_class  => 'Digest',
       encode_args   => {algorithm => 'MD5', format => 'base64'},
-      digest_check_method => 'check_password',
+      encode_check_method => 'check_password',
   }
 
   #Eksblowfish bcrypt / cost of 8/ no key_nul / generate check method
@@ -114,7 +117,7 @@ In your L<DBIx::Class> Result class
       encode_column => 1,
       encode_class  => 'Crypt::Eksblowfish::Bcrypt',
       encode_args   => { key_nul => 0, cost => 8 },
-      digest_check_method => 'check_password',
+      encode_check_method => 'check_password',
   }
 
 In your application code:
@@ -148,7 +151,7 @@ and C<EncodedColumn> performs the operation when the value is set, or on C<new>.
 =item C<DigestColumns> supports only algorithms of the L<Digest> family.
 C<EncodedColumn> employs a set of thin wrappers around different cipher modules
 to provide support for any cipher you wish to use and wrappers are very simple
-to write (typicall less than 30 lines).
+to write (typically less than 30 lines).
 
 =item C<EncodedColumn> supports having more than one encoded column per table
 and each column can use a different cipher.
@@ -156,10 +159,12 @@ and each column can use a different cipher.
 =item C<Encode> adds only one item to the namespace of the object utilizing
 it (C<_column_encoders>).
 
-There is, unfortunately, some features that C<EncodedColumn> doesn't suppor.
+=back
+
+There is, unfortunately, some features that C<EncodedColumn> doesn't support.
 C<DigestColumns> supports changing certain options at runtime, as well as
 the option to not automatically encode values on set. The author of this module
-found these options to be non-essential and ommitted them by design.
+found these options to be non-essential and omitted them by design.
 
 =head1 Options added to add_column
 
@@ -169,29 +174,37 @@ column and all of the defaults will be applied to the rest of the options.
 =head2 encode_enable => 1
 
 Enable automatic encoding of column values. If this option is not set to true
-any other options will become noops.
+any other options will become no-ops.
 
 =head2 encode_check_method => $method_name
 
-By using the digest_check_method attribute when you declare a column you
+By using the encode_check_method attribute when you declare a column you
 can create a check method for that column. The check method accepts a plain
 text string, and returns a boolean that indicates whether the digest of the
 provided value matches the current value.
 
-=head2 digest_class
+=head2 encode_class
 
-The class to use for encoding. available classes are:
+The class to use for encoding. Available classes are:
 
 =over 4
 
-=item C<Crypt::Eksblowfish::Bcrypt> - uses L<DBIx::Class::EncodedColumn::Crypt::Eksblowfish::Bcrypt>
+=item C<Crypt::Eksblowfish::Bcrypt> - uses
+L<DBIx::Class::EncodedColumn::Crypt::Eksblowfish::Bcrypt> and 
+requires L<Crypt::Eksblowfish::Bcrypt> to be installed
 
 =item C<Digest> - uses L<DBIx::Class::EncodedColumn::Digest>
+requires L<Digest> to be installed as well as the algorithm required
+(L<Digest::SHA>, L<Digest::Whirlpool>, etc)
+
+=item C<Crypt::OpenPGP> - L<DBIx::Class::EncodedColumn::Crypt::OpenPGP>
+and requires L<Crypt::OpenPGP> to be installed
 
 =back
 
 Please see the relevant class's documentation for information about the
-specific arguments accepted by each.
+specific arguments accepted by each and make sure you include the encoding
+algorithm (e.g. L<Crypt::OpenPGP>) in your application's requirements.
 
 =head1 EXTENDED METHODS
 
@@ -225,8 +238,20 @@ Inspired by the original module written by Tom Kirkpatrick (tkp) <tkp@cpan.org>
 featuring contributions from Guillermo Roditi (groditi) <groditi@cpan.org>
 and Marc Mims <marc@questright.com>
 
+=head1 CONTRIBUTORS
+
+kentnl - Kent Fredric <kentnl@cpan.org>
+
+mst - Matt S Trout <mst@shadowcat.co.uk>
+
+=head1 COPYRIGHT
+
+Copyright (c) 2008 - 2009 the DBIx::Class::EncodedColumn L</AUTHOR> and
+L</CONTRIBUTORS> as listed above.
+
 =head1 LICENSE
 
-You may distribute this code under the same terms as Perl itself.
+This library is free software and may be distributed under the same terms
+as perl itself.
 
 =cut
